# Please keep this package in sync with FC

# "fix" underlinking:
%define _disable_ld_no_undefined 1
%global _debugsource_packages 0

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
%{!?enable_autotools:%global enable_autotools 0}

%define server_drivers     1
%define with_libxl         0%{!?_without_libxl:%{server_drivers}}
# Xen is available only on i386 x86_64 ia64
%ifnarch %{ix86} x86_64 ia64
    %define with_libxl 0
%endif

%define common_summary interact with virtualization capabilities
%define common_description Libvirt is a C toolkit to interact with the virtualization\
capabilities of recent versions of Linux.

%define lib_major 0
%define nss_major 2

%define lib_name %mklibname virt %{lib_major}
%define nss_name %mklibname nss_libvirt %{nss_major}
%define develname %mklibname -d virt
%define staticdevelname %mklibname -d -s virt

# libxenstore is not versionned properly
%global __requires_exclude devel\\(libxenstore.*\\)

%define enable_werror --disable-werror

    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)

Summary:    Toolkit to %{common_summary}
Name:       libvirt
Version:    5.5.0
%define     subrel 2
Release:    %mkrel 1
License:    LGPLv2+
Group:      System/Kernel and hardware
URL:        https://libvirt.org/

%if %(echo %{version} | grep -o \\. | wc -l) == 3
    %define mainturl stable_updates/
%endif
Source:	    https://libvirt.org/sources/%{?mainturl}libvirt-%{version}.tar.xz
Source1:    %{name}-tmpfiles.conf

# upstream master
# https://security-tracker.debian.org/tracker/CVE-2020-10703
Patch0:  16a7c261f8d28e3abe60a47165f845fa952f.patch
# https://security-tracker.debian.org/tracker/CVE-2020-12430
Patch1:  9bf9e0ae6af38c806f4672ca7b12a6b38d5a9581.patch
# https://security-tracker.debian.org/tracker/CVE-2019-20485
Patch2:  a663a860819287e041c3de672aad1d8543098ecc.patch

Patch10: fix-compiling-with-wireshark3.patch

# Fedora patches:
 
Requires:   cyrus-sasl
# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  perl
BuildRequires:  python2
BuildRequires:  systemd-units
BuildRequires:  systemd-devel
%if %{with_libxl}
BuildRequires:  xen-devel
%endif
BuildRequires:  libxml2-devel
BuildRequires:  xsltproc 
BuildRequires:  readline-devel
BuildRequires:	bash-completion >= 2.0
BuildRequires:  ncurses-devel
BuildRequires:  gettext
BuildRequires:  libtasn1-devel
BuildRequires:  gnutls-devel
BuildRequires:  libattr-devel
# For pool-build probing for existing pools
BuildRequires:  libblkid-devel >= 2.17
BuildRequires:  libxml2-utils
BuildRequires:  xmlrpc-c-devel
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires:  libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
# make sure libvirt is built with new enough sanlock on
# distros that have it; required for on_lockfailure
#BuildRequires:  sanlock-devel >= 2.4
BuildRequires:  libpcap-devel
# (tmb) build against kernel-devel-latest
BuildRequires:  kernel-desktop-devel-latest
# (tmb) use fixed headers with kvm*.h exported
BuildRequires:	kernel-userspace-headers >= 4.14.32-1

BuildRequires:  libnl3-devel
BuildRequires:  dnsmasq >= 2.41
BuildRequires:  iptables
BuildRequires:  iptables-ipv6
BuildRequires:  parted
BuildRequires:  radvd
BuildRequires:  libsasl-devel
#BuildRequires:  ebtables
BuildRequires:  module-init-tools
# F22 polkit-devel doesn't pull in polkit anymore, which we need for pkcheck
BuildRequires:  polkit >= 0.112
# For mount/umount in FS driver
BuildRequires: util-linux
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires:  qemu-img
# For LVM drivers
BuildRequires:  lvm2
# For pool type=iscsi
BuildRequires:  iscsi-initiator-utils
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
# For disk driver
BuildRequires:  parted-devel
# Broken RHEL-5 parted RPM is missing a dep
BuildRequires: e2fsprogs-devel
# For Multipath support
BuildRequires:  device-mapper
BuildRequires:  device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
# glusterfs was dropped in mga6 as unmaintained
#BuildRequires:  glusterfs-devel >= 3.4.0
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse
%ifnarch %{arm} aarch64
BuildRequires: zfs-fuse
%endif
# For QEMU/LXC numa info
%ifnarch %{arm}
BuildRequires:  numa-devel
BuildRequires:  numactl
%endif
BuildRequires:  libcap-ng-devel >= 0.5.0
BuildRequires:  fuse-devel >= 2.8.6
BuildRequires:  libssh2-devel >= 1.3.0
BuildRequires:	libtirpc-devel
BuildRequires:  netcf-devel >= 0.2.2
BuildRequires:  curl-devel
# (tv) For hyper-V support, we need openwsman (which needs sblim-sfcc-devel)
%if 0
BuildRequires: libwsman-devel >= 2.2.3
%endif
BuildRequires:  systemtap
# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires:  nfs-utils

# Communication with the firewall and polkit daemons use DBus
BuildRequires:  dbus-devel

BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires:  scrub
%ifnarch %{arm}
BuildRequires:  numad
%endif
# for the wireshark plugin
BuildRequires:  wireshark-devel >= 2.4.0
BuildRequires:  wireshark
BuildRequires:  libssh-devel >= 0.7.0

%description
%{common_description}

Virtualization of the Linux Operating System means the
ability to run multiple instances of Operating Systems concurently on
a single hardware system where the basic resources are driven by a
Linux instance. The library aim at providing long term stable C API
initially for the Xen paravirtualization but should be able to
integrate other virtualization mechanisms if needed.

%package docs
Summary: API reference and website documentation
Group: Documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package -n %{lib_name}
Summary:    A library to %{common_summary}
Group:      System/Libraries
# For LXC move (mga#14566)
Conflicts:  %{develname} <  %version-%release

%description -n %{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:    Development tools for programs using %{name}
Group:      Development/C
Requires:   %{lib_name} = %{version}
%if %{with_libxl}
Requires:   xen-devel
%endif
Provides:   %{name}-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-devel
# For LXC move (mga#14566)
Conflicts:  %{lib_name} <  %version-%release
# For api/*.xml move:
Conflicts:  libvirt-utils < 1.3.4-2

%description -n %{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%package -n %{staticdevelname}
Summary:    Development static libraries for programs using %{name}
Group:      Development/C
Provides:   %{name}-static-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-static-devel

%description -n %{staticdevelname}
%{common_description}

This package contains the static libraries needed for developing
programs using the %{name} library.

%package -n %{name}-utils
Summary:    Tools to %{common_summary}
Group:      System/Kernel and hardware
Requires:   bridge-utils
Requires:   %{lib_name} = %{version}
Requires:   polkit
Requires:   ebtables
Requires:   netcf
# required by libvirt-guests.service
Requires:   gettext
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
# fix "Cannot check dnsmasq binary dnsmasq":
Recommends:   dnsmasq
Recommends:   netcat-openbsd
Conflicts:  libvirt0 < 0.7.1-2
Conflicts:  lib64virt0 < 0.7.1-2
Provides:   %{name}-client = %{version}-%{release}
Requires: qemu-kvm
Requires: qemu-img
Requires: iptables

%description -n %{name}-utils
%{common_description}

This package contains tools for the %{name} library.

%package -n wireshark-%{name}
Summary: Wireshark dissector plugin for libvirt RPC transactions
Group: Monitoring
Requires: wireshark

%description -n wireshark-%{name}
Wireshark dissector plugin for better analysis of libvirt RPC traffic.

%package -n %nss_name
Summary: Libvirt plugin for Name Service Switch
# temp cauldron fix before mga7:
Obsoletes: %{mklibname virt 2} < %version-%release
Provides: %{mklibname virt 2} = %version-%release

%description -n %nss_name
Libvirt plugin for NSS for translating domain names into IP addresses.

%prep
%setup -q
%autopatch -p1

%build

%if 0%{?mageia}
    # Nightly edk2.git-ovmf-x64
    LOADERS="/usr/share/edk2.git/ovmf-x64/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-x64/OVMF_VARS-pure-efi.fd"
    # Nightly edk2.git-ovmf-ia32
    LOADERS="$LOADERS:/usr/share/edk2.git/ovmf-ia32/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-ia32/OVMF_VARS-pure-efi.fd"
    # Nightly edk2.git-aarch64
    LOADERS="$LOADERS:/usr/share/edk2.git/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2.git/aarch64/vars-template-pflash.raw"
    # Nightly edk2.git-arm
    LOADERS="$LOADERS:/usr/share/edk2.git/arm/QEMU_EFI-pflash.raw:/usr/share/edk2.git/arm/vars-template-pflash.raw"

    # Fedora edk2-ovmf
    LOADERS="$LOADERS:/usr/share/edk2/ovmf/OVMF_CODE.fd:/usr/share/edk2/ovmf/OVMF_VARS.fd"
    # Fedora edk2-ovmf-ia32
    LOADERS="$LOADERS:/usr/share/edk2/ovmf-ia32/OVMF_CODE.fd:/usr/share/edk2/ovmf-ia32/OVMF_VARS.fd"
    # Fedora edk2-aarch64
    LOADERS="$LOADERS:/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2/aarch64/vars-template-pflash.raw"
    # Fedora edk2-arm
    LOADERS="$LOADERS:/usr/share/edk2/arm/QEMU_EFI-pflash.raw:/usr/share/edk2/arm/vars-template-pflash.raw"
    %define arg_loader_nvram --with-loader-nvram="$LOADERS"
%endif

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%if 0%{?enable_autotools}
autoreconf -if
%endif
# fix compiling wireshark plugin:
export CFLAGS="`pkg-config --cflags glib-2.0` $CFLAGS"
%configure2_5x --disable-static \
    --localstatedir=%{_var}  \
    --with-numactl \
%ifarch %{arm}
    --without-numactl \
    --without-numad \
%endif
    --with-udev \
    --with-yajl \
    --without-hal \
    --with-init_script=systemd \
    --with-openssl \
    --without-selinux \
    --without-selinux-mount \
    --with-test-suite \
    --with-nss-plugin \
    %{?arg_loader_nvram} \
    %{?enable_werror} \
    --with-wireshark-dissector
%make V=1
gzip -9 ChangeLog

%install
%make_install SYSTEMD_UNIT_DIR=%{_unitdir}

rm -f %{buildroot}%{_initrddir}/libvirt-guests
find %{buildroot} -name '*.la' -delete

install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}%{_var}/lib/%{name}
%find_lang %{name}

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs


%check
cd tests
# These tests don't current work in a mock build root
for i in nodeinfotest seclabeltest
do
  rm -f $i
  printf 'int main(void) { return 0; }' > $i.c
  printf '#!/bin/sh\nexit 0\n' > $i
  chmod +x $i
done
if ! make check VIR_TEST_DEBUG=1
then
  cat test-suite.log || true
  #exit 1
fi

%post -n %{name}-utils
%_tmpfilescreate %{name}
%_post_service  libvirtd
%_post_service  libvirt-guests
%_post_service	virtlockd

%preun -n %{name}-utils
%_preun_service libvirt-guests
%_preun_service libvirtd
%_preun_service	virtlockd

%files docs
%doc AUTHORS ChangeLog.gz NEWS README README.md
%doc libvirt-docs/*
#doc docs/*.html docs/html docs/*.gif
%doc docs/*.css

# API docs
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css


%files -n %{lib_name}
%license COPYING COPYING.LESSER
%{_libdir}/%{name}.so.%{lib_major}{,.*}
%{_libdir}/%{name}-admin.so.%{lib_major}{,.*}
%{_libdir}/%{name}-qemu.so.%{lib_major}{,.*}
%{_libdir}/%{name}-lxc.so.%{lib_major}{,.*}

%files -n %nss_name
%{_libdir}/libnss_libvirt.so.%{nss_major}{,.*}
%{_libdir}/libnss_libvirt_guest.so.%{nss_major}{,.*}


%files -n %{develname}
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/%{name}-admin.so
%{_libdir}/%{name}-qemu.so
%{_libdir}/%{name}-lxc.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-lxc.pc
%{_libdir}/pkgconfig/%{name}-qemu.pc
%{_libdir}/pkgconfig/%{name}-admin.pc
# Needed building python bindings
%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml

%files -n %{name}-utils -f %{name}.lang
%doc README NEWS
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man7/*
%{_mandir}/man8/*
%{_sbindir}/*
%{_unitdir}/libvirtd.service
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%{_libexecdir}/libvirt_lxc
%{_libexecdir}/libvirt_leaseshelper
%{_libexecdir}/libvirt_parthelper
%{_libexecdir}/libvirt_iohelper
%{_libexecdir}/libvirt-guests.sh
%{_var}/lib/libvirt
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules
%{_datadir}/augeas/lenses/*.aug
%{_datadir}/augeas/lenses/tests/*.aug
%{_datadir}/systemtap/tapset/*.stp
%{_datadir}/bash-completion/completions/vsh
%{_datadir}/%{name}
%exclude %{_datadir}/libvirt/api/
%exclude %{_datadir}/libvirt/api/*.xml
%config(noreplace) %{_sysconfdir}/libvirt
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd*
%{_prefix}/lib/sysctl.d/*.conf
%{_unitdir}/libvirt-guests.service
%{_tmpfilesdir}/%{name}.conf
%{_libdir}/libvirt/connection-driver
%{_prefix}/lib/firewalld/zones/libvirt.xml
%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %{_libdir}/libvirt/lock-driver
%{_libdir}/libvirt/lock-driver/*.so
%{_libdir}/libvirt/storage-backend/*.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so
%{_datadir}/bash-completion/completions/

%files -n wireshark-%{name}
%{wireshark_plugindir}/epan/libvirt.so


%changelog
* Sun Jun 21 2020 neoclust <neoclust> 5.5.0-1.2.mga7
+ Revision: 1598174
- Add P2: Fix CVE-2019-20485 (mga#26816)
- Add P0 and P1 to fix CVE-2020-10703 and CVE-2020-12430 ( mga#26600 )
+ tv <tv>
- 5.5.0 security update -- https://libvirt.org/news.html#v5.5.0
  o api: Prevent access to several APIs over read-only connections
    Certain APIs give root-equivalent access to the host, and as such should be
    limited to privileged users. CVE-2019-10161, CVE-2019-10166, CVE-2019-10167,
    CVE-2019-10168.
- it also contains the security fixes from 5.4.0:
  o cpu: Introduce support for the md-clear CPUID bit
    This bit is set when microcode provides the mechanism to invoke a flush of
    various exploitable CPU buffers by invoking the x86 VERW instruction.
    CVE-2018-12126, CVE-2018-12127, CVE-2018-12130, CVE-2019-11091.
  o Restrict user access to virt-admin, virtlogd and virtlockd
    The intended users for these facilities are the root user and the libvirtd
    service respectively, but these restrictions were not enforced correctly.
    CVE-2019-10132.

* Wed May 15 2019 tmb <tmb> 5.3.0-2.mga7
+ Revision: 1397846
- cputest: Add data for Intel(R) Xeon(R) CPU E3-1225 v5
- cpu_map: Define md-clear CPUID bit (CVE-2018-12126, CVE-2018-12127,
  CVE-2018-12130, CVE-2019-11091)

* Wed May 08 2019 tv <tv> 5.3.0-1.mga7
+ Revision: 1396772
- new release

* Sun Apr 14 2019 tv <tv> 5.2.0-2.mga7
+ Revision: 1389971
- Rebuild against xen 4.12

* Wed Apr 03 2019 tv <tv> 5.2.0-1.mga7
+ Revision: 1385583
- 5.2.0

* Thu Mar 21 2019 tv <tv> 5.1.0-2.mga7
+ Revision: 1379414
- BR xfsprogs-devel for XFS reflink clone support
- Fix use of deprecated RBD features
- Avoid using firewalld if unprivileged
- Don't require ipv6 firewall support at startup (rhbz#1688968)

* Tue Mar 05 2019 tv <tv> 5.1.0-1.mga7
+ Revision: 1371613
- fix wireshark plugin filelist
- fix compiling with wireshark 3
- new release

* Thu Jan 24 2019 tv <tv> 5.0.0-2.mga7
+ Revision: 1360532
- temporary disable BR on ebtables as iptables is providing/conflicting with it
- new release

* Mon Dec 03 2018 tv <tv> 4.10.0-1.mga7
+ Revision: 1338177
- 4.10.0
- requires iptables (mga#22213)

* Tue Nov 13 2018 tv <tv> 4.9.0-1.mga7
+ Revision: 1329711
- new release

* Sat Oct 13 2018 tv <tv> 4.8.0-2.mga7
+ Revision: 1319965
- fix nss library package name
- fix deps

* Sun Oct 07 2018 tv <tv> 4.8.0-1.mga7
+ Revision: 1318410
- new release

* Thu Sep 13 2018 tv <tv> 4.7.0-6.mga7
+ Revision: 1258922
- rebuild for new xen
+ wally <wally>
- fix typo in configure options on arm

* Tue Sep 11 2018 wally <wally> 4.7.0-5.mga7
+ Revision: 1258451
- build without numad and numactl on arm

* Tue Sep 11 2018 wally <wally> 4.7.0-4.mga7
+ Revision: 1258427
- don't BR zfs-fuse on arm and aarch64

* Mon Sep 10 2018 tv <tv> 4.7.0-3.mga7
+ Revision: 1258136
- enable extra 32bit firmwares (OVMF-ia32 & arm)

* Thu Sep 06 2018 tv <tv> 4.7.0-2.mga7
+ Revision: 1257514
- enable nss & numad support
- enable support for numactl & nss
- enable ZFS support
- rebuild with libiscsi >= 1.18.0 for iscsi-direct support

* Thu Sep 06 2018 tv <tv> 4.7.0-1.mga7
+ Revision: 1257450
- ignore testsuite failure on BS as it succeeds locally
- BR augparse for testsuite
- new release

* Wed Aug 08 2018 tv <tv> 4.6.0-1.mga7
+ Revision: 1250365
- new release
- Fix regressions with chardev handling

* Wed Jul 04 2018 tv <tv> 4.5.0-1.mga7
+ Revision: 1241665
- new release

* Wed Jun 06 2018 tv <tv> 4.4.0-1.mga7
+ Revision: 1234976
- new release

* Wed May 09 2018 zezinho <zezinho> 4.3.0-3.mga7
+ Revision: 1227855
- recommends netcat-openbsd as we nc -U mga#22991

* Sat May 05 2018 tv <tv> 4.3.0-2.mga7
+ Revision: 1226620
- fix filelist
- 4.3.0

* Tue Apr 03 2018 tv <tv> 4.2.0-1.mga7
+ Revision: 1215041
- new release

* Sun Apr 01 2018 tv <tv> 4.2.0-0.1rc2.mga7
+ Revision: 1214034
- 4.2.0 RC2

* Sun Apr 01 2018 tmb <tmb> 4.2.0-0.1rc1.2.mga7
+ Revision: 1213997
- rebuild against fixed kernel-userspace-headers

* Wed Mar 28 2018 tv <tv> 4.2.0-0.1rc1.1.mga7
+ Revision: 1213236
- 4.2.0 RC1

* Wed Mar 28 2018 tv <tv> 4.1.0-3.mga7
+ Revision: 1213197
- do not uselessly run slooow autoreconf
- fix building w/o linux/kvm.h (which disabled KVM support)
- advertize new OVMF location
- Update Python 2 dependency declarations to new packaging standards

* Wed Mar 21 2018 mrambo3501 <mrambo3501> 4.1.0-2.mga7
+ Revision: 1211131
- add upstream patch which fixes CVE-2018-1064 (mga#22777)

* Thu Mar 08 2018 tv <tv> 4.1.0-1.mga7
+ Revision: 1207441
- new release

* Sat Feb 03 2018 tv <tv> 4.0.0-3.mga7
+ Revision: 1198744
- rebuild for new xen

* Tue Jan 23 2018 tv <tv> 4.0.0-1.mga7
+ Revision: 1196568
- new release

* Wed Dec 06 2017 tv <tv> 3.10.0-1.mga7
+ Revision: 1181471
- new release
- new release

* Sat Nov 04 2017 tv <tv> 3.9.0-1.mga7
+ Revision: 1175817
- new release

* Wed Oct 04 2017 tv <tv> 3.8.0-1.mga7
+ Revision: 1168657
- new release
- new release

* Tue Sep 05 2017 tv <tv> 3.7.0-1.mga7
+ Revision: 1151323
- new release
- rebuild for new python

* Thu Aug 03 2017 tv <tv> 3.6.0-1.mga7
+ Revision: 1134492
- new release

* Wed Jul 19 2017 tv <tv> 3.5.0-1.mga7
+ Revision: 1125154
- new release

* Thu May 25 2017 mrambo3501 <mrambo3501> 3.3.0-1.mga6
+ Revision: 1104524
- version 3.3.0 fixes CVE-2015-5160 (#19717)
- deleted two patches applied upstream
- deleted the systemd patch which no longer applies

* Wed May 03 2017 akien <akien> 1.3.5-5.mga6
+ Revision: 1098914
- Disable glusterfs support, the package was dropped in mga6 as unmaintained

* Fri Aug 19 2016 blino <blino> 1.3.5-4.mga6
+ Revision: 1046966
- recommend virtual netcat package instead of specific netcat-openbsd (to avoid conflict with task-printing which requires netcat-traditional), libvirt supports both as of commit a2b5c57db83559d4fe32ee90fbb6685555388e06 from 2011

* Thu Jul 07 2016 luigiwalser <luigiwalser> 1.3.5-3.mga6
+ Revision: 1039476
- add upstream patch to fix CVE-2016-5008

* Wed Jun 29 2016 tv <tv> 1.3.5-2.mga6
+ Revision: 1038152
- patch 100: add support for VirtualBox 5

* Tue Jun 07 2016 tv <tv> 1.3.5-1.mga6
+ Revision: 1020554
- new release

* Sat May 21 2016 tv <tv> 1.3.4-4.mga6
+ Revision: 1017279
- Fix libxl video config via virt-install (bz #1334557)

* Wed May 04 2016 tv <tv> 1.3.4-3.mga6
+ Revision: 1009081
- better docs: include CSS files
- do not BR the full qemu

* Tue May 03 2016 tv <tv> 1.3.4-2.mga6
+ Revision: 1008950
- adjust file list
- move api XML files back into devel (needed for python-libvirt build)
- split docs sub package

* Tue May 03 2016 tv <tv> 1.3.4-1.mga6
+ Revision: 1008907
- new release

* Tue Apr 26 2016 tv <tv> 1.3.3-5.mga6
+ Revision: 1006540
- requires qemu-kvm
- requires qemu-img
- document we need openwsman for Hyper-V support
- disable Werror

* Wed Apr 20 2016 tv <tv> 1.3.3-4.mga6
+ Revision: 1003879
- temporary disable sanlock support
- BR basesystems libtasn1-devel + libattr-devel
- BR sanlock-devel
- BR glusterfs-devel
- BR iptables-ipv6
- BR e2fsprogs-devel as it's not pulled by parted-devel
- BR basesystems libcap-ng-devel + fuse-devel
- BR xen for qcow-create
- BR dbus-devel + device-mapper-devel

* Wed Apr 20 2016 tv <tv> 1.3.3-3.mga6
+ Revision: 1003722
- libvirt assigns same address to two PCI devices (rhbz#1325085)
- fix 200ms performance problem when waiting for monitor socket of new domains

* Sun Apr 17 2016 tv <tv> 1.3.3-2.mga6
+ Revision: 1003278
- advertise OVMF and AAVMF

* Wed Apr 06 2016 luigiwalser <luigiwalser> 1.3.3-1.mga6
+ Revision: 999010
- disable nss plugin for now
- 1.3.3

* Sun Apr 03 2016 tv <tv> 1.3.2-3.mga6
+ Revision: 997798
- rebuild for new xen

* Wed Mar 23 2016 tv <tv> 1.3.2-2.mga6
+ Revision: 994296
- add more fixes from FC
- do not package huge ChangeLog in library pkg

* Wed Mar 16 2016 tv <tv> 1.3.2-1.mga6
+ Revision: 992071
- adjust file list
- adjust file list
- new release
- drop merged patches
- add one patch from FC

* Wed Mar 16 2016 tv <tv> 1.2.9.3-8.mga6
+ Revision: 991913
- BR wireshark thus fixing build
- rediff unappliable patch 62
+ oden <oden>
- build and provide the wireshark plugin

* Thu Mar 03 2016 doktor5000 <doktor5000> 1.2.9.3-7.mga6
+ Revision: 984899
- disable selinux support as tests fail to build against latest libselinux
- added upstream fixes for failing vircgrouptest on buildsystem
- do not skip vircgrouptest to verify if it runs on buildsystem

* Wed Feb 24 2016 doktor5000 <doktor5000> 1.2.9.3-6.mga6
+ Revision: 978706
- skip test vircgrouptest, fails on buildsystem
- added method to skip specific tests, from openSUSE
- prepare to disable vircgrouptest, which fails on buildsystem
- enable debug logging for tests with VIR_TEST_DEBUG=1
- enable tracing for debugging purposes
- exit build after %%check section for access to logs on buildsystem

* Tue Feb 23 2016 doktor5000 <doktor5000> 1.2.9.3-5.mga6
+ Revision: 977155
- added BuildRequires on xhtml1-dtds to prevent build failing
- enable building of testsuite
- reenable tests in %%check section

* Wed Jan 27 2016 cjw <cjw> 1.2.9.3-4.mga6
+ Revision: 928206
- drop patch0 as it makes qemu connections fail completely
- remove some trailing whitespace from spec file lines

* Mon Jan 11 2016 luigiwalser <luigiwalser> 1.2.9.3-3.mga6
+ Revision: 921822
- rebuild for gnutls

* Thu Dec 31 2015 blino <blino> 1.2.9.3-2.mga6
+ Revision: 917088
- buildrequire kernel-desktop devel instead of deprecated kirkwood flavor on ARM

* Tue Dec 29 2015 luigiwalser <luigiwalser> 1.2.9.3-1.mga6
+ Revision: 916820
- 1.2.9.3
- sync with upstream git including fix for CVE-2015-5313
+ pterjan <pterjan>
- No numactl on arm

* Sun May 10 2015 tv <tv> 1.2.9.2-2.mga5
+ Revision: 821611
- move LXC driver from devel to main package (mga#14566)

* Tue Mar 03 2015 luigiwalser <luigiwalser> 1.2.9.2-1.mga5
+ Revision: 817500
- 1.2.9.2
- remove upstreamed patches
- add latest upstream patches from 1.2.9 git branch as of 2015-02-26

* Tue Feb 03 2015 akien <akien> 1.2.9.1-5.mga5
+ Revision: 813311
- Rebuild for new xen

* Tue Jan 27 2015 luigiwalser <luigiwalser> 1.2.9.1-4.mga5
+ Revision: 812442
- sync upstream patches including fix for CVE-2015-0236

* Thu Dec 25 2014 luigiwalser <luigiwalser> 1.2.9.1-3.mga5
+ Revision: 805994
- sync upstream patches to fix CVE-2014-8135 and CVE-2014-8136

* Tue Dec 16 2014 luigiwalser <luigiwalser> 1.2.9.1-2.mga5
+ Revision: 803300
- sync upstream patches including fix for CVE-2014-8131

* Thu Dec 11 2014 luigiwalser <luigiwalser> 1.2.9.1-1.mga5
+ Revision: 802756
- 1.2.9.1

* Thu Nov 13 2014 luigiwalser <luigiwalser> 1.2.9-3.mga5
+ Revision: 796782
- sync patches from upstream 1.2.9 branch, including fix for CVE-2014-7823

* Wed Oct 15 2014 umeabot <umeabot> 1.2.9-2.mga5
+ Revision: 740377
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 luigiwalser <luigiwalser> 1.2.9-1.mga5
+ Revision: 733839
- 1.2.9 (fixes CVE-2014-3633 and CVE-2014-3657)

* Tue Sep 16 2014 umeabot <umeabot> 1.2.8-3.mga5
+ Revision: 681841
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Wed Sep 03 2014 joequant <joequant> 1.2.8-2.mga5
+ Revision: 671577
- bump version
- build with new systemd

* Wed Sep 03 2014 luigiwalser <luigiwalser> 1.2.8-1.mga5
+ Revision: 671143
- add libvirtd.socket to files list
- 1.2.8
+ alien <alien>
- require gettext for libvirt-guests.service

* Tue Aug 05 2014 sander85 <sander85> 1.2.7-1.mga5
+ Revision: 659794
- New version: 1.2.7

* Sun Jul 27 2014 sander85 <sander85> 1.2.6-1.mga5
+ Revision: 657477
- New version: 1.2.6

* Wed Jun 04 2014 fwang <fwang> 1.2.5-1.mga5
+ Revision: 632734
- 1.2.5

* Sun May 18 2014 tmb <tmb> 1.2.4-2.mga5
+ Revision: 623566
- fix CVE-2014-0179

* Sun May 18 2014 tmb <tmb> 1.2.4-1.mga5
+ Revision: 623534
- update to 1.2.4
+ fwang <fwang>
- 1.2.3

* Sun Mar 30 2014 tv <tv> 1.2.2-2.mga5
+ Revision: 610327
- rebuild for new xen

* Sat Mar 15 2014 joequant <joequant> 1.2.2-1.mga5
+ Revision: 603999
- upgrade to 1.2.2

* Fri Jan 24 2014 oden <oden> 1.2.1-1.mga4
+ Revision: 567696
- 1.2.1 (fixes CVE-2013-6436, CVE-2013-6457, CVE-2013-6458, CVE-2014-0028, CVE-2014-1447)

* Mon Nov 11 2013 luigiwalser <luigiwalser> 1.1.4-1.mga4
+ Revision: 550558
- 1.1.4 (fixes CVE-2013-4400 and CVE-2013-4401)

* Tue Oct 22 2013 umeabot <umeabot> 1.1.3-4.mga4
+ Revision: 545429
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 alien <alien> 1.1.3-3.mga4
+ Revision: 501003
- rebuild for XEN 4.3.0

* Thu Oct 10 2013 joequant <joequant> 1.1.3-2.mga4
+ Revision: 494792
- add netcf dependency

* Wed Oct 09 2013 luigiwalser <luigiwalser> 1.1.3-1.mga4
+ Revision: 494281
- 1.1.3
- remove upstream patches
- add 6 patches from fedora
+ oden <oden>
- fix build deps

* Sun Sep 22 2013 colin <colin> 1.1.2-2.mga4
+ Revision: 483291
- Make polkit usage secure (mga#11260 CVE-2013-4311)

* Fri Sep 06 2013 fwang <fwang> 1.1.2-1.mga4
+ Revision: 475396
- new version 1.1.2 final

* Sat Aug 31 2013 joequant <joequant> 1.1.2-0.1.mga4
+ Revision: 473756
- upgrade to 1.1.2rc2

* Tue Aug 27 2013 luigiwalser <luigiwalser> 1.1.1-7.mga4
+ Revision: 472078
- rebuild for cyrus-sasl

* Mon Aug 26 2013 joequant <joequant> 1.1.1-6.mga4
+ Revision: 471876
- add buildrequires for dnsmasq to get location of libvirt

* Sun Aug 25 2013 joequant <joequant> 1.1.1-5.mga4
+ Revision: 471680
- put in nodaemonize patch

* Sat Aug 17 2013 joequant <joequant> 1.1.1-3.mga4
+ Revision: 467357
- add redhat patch to fix segfault.  This is needed for openstack nova

* Wed Jul 31 2013 fwang <fwang> 1.1.1-2.mga4
+ Revision: 461385
- add more br
- use autoreconf
- new version 1.1.1

* Mon Jul 29 2013 neoclust <neoclust> 1.1.0-1.mga4
+ Revision: 460623
- New version

* Tue Jun 04 2013 fwang <fwang> 1.0.6-1.mga4
+ Revision: 437152
- new version 1.0.6

* Wed May 29 2013 fwang <fwang> 1.0.5-2.mga4
+ Revision: 432620
- add upstream patch fixing CVE-2013-1962

* Sat May 25 2013 blino <blino> 1.0.5-1.mga4
+ Revision: 427670
- drop cherry-picks
- 1.0.5

* Sat Mar 30 2013 tv <tv> 1.0.2-7.mga3
+ Revision: 406773
- add patches from FC (fix creating a VM with xen)
- suggests dnsmasq instead of dnsmasq-base
  (fix "Cannot check dnsmasq binary dnsmasq")

* Sun Mar 24 2013 colin <colin> 1.0.2-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Mar 10 2013 alien <alien> 1.0.2-5.mga3
+ Revision: 402029
- fix connection loss issue

* Fri Mar 08 2013 alien <alien> 1.0.2-4.mga3
+ Revision: 401739
- XEN: do not force blktap as disk backend

* Wed Feb 06 2013 rtp <rtp> 1.0.2-3.mga3
+ Revision: 394827
- backport upstream fix for the python binding

* Tue Feb 05 2013 rtp <rtp> 1.0.2-2.mga3
+ Revision: 394735
- fix qemu commandline when probing capabilities

* Wed Jan 30 2013 guillomovitch <guillomovitch> 1.0.2-1.mga3
+ Revision: 393598
- new version
+ tmb <tmb>
- fix inclusion order in P4

* Mon Jan 14 2013 tmb <tmb> 1.0.1-6.mga3
+ Revision: 388067
- work around broken kernel headers (if_bridge.h not selfcontainted) (P4, upstream)
+ colin <colin>
- Use kernel-source instead. Headers seems not enough.
- Add kernel-headers to build requires
- Switch to tmpfiles for [/var]/run dirs
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 cjw <cjw> 1.0.1-3.mga3
+ Revision: 343403
- patch3: fix path substitution in virtlockd.service

* Wed Jan 02 2013 pterjan <pterjan> 1.0.1-2.mga3
+ Revision: 337481
- Fix for _libdir != _libexecdir

* Tue Dec 18 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 332243
- update file list
- new version 1.0.1

* Thu Nov 22 2012 blino <blino> 1.0.0-2.mga3
+ Revision: 320995
- require ebtables for libvirtd

* Mon Nov 05 2012 fwang <fwang> 1.0.0-1.mga3
+ Revision: 314304
- new version 1.0.0

* Wed Sep 26 2012 fwang <fwang> 0.10.2-1.mga3
+ Revision: 297893
- new version 0.10.2
- drop unused patch

* Sat Sep 01 2012 fwang <fwang> 0.10.1-1.mga3
+ Revision: 286791
- new version 0.10.1

* Tue Aug 14 2012 guillomovitch <guillomovitch> 0.9.13-3.mga3
+ Revision: 281317
- drop sysinit support

* Fri Aug 03 2012 fwang <fwang> 0.9.13-2.mga3
+ Revision: 278265
- more dir fix
- fix systemd unit dir
- rebuild for new parted

* Sat Jul 14 2012 tv <tv> 0.9.13-1.mga3
+ Revision: 270667
- adjust file list
- rediff patch 1
- new release

* Sat Jun 30 2012 colin <colin> 0.9.12-2.mga3
+ Revision: 265337
- Hopefully fix build against libnl3
- Rebuild against new libudev major
+ ovitters <ovitters>
- drop patch 1\n-new version 0.9.12

* Mon May 28 2012 blino <blino> 0.9.10-6.mga3
+ Revision: 248291
- call post/preun scripts for libvirtd and libvirt-guests services

* Sat Apr 28 2012 tmb <tmb> 0.9.10-5.mga2
+ Revision: 233764
- Require rpm-helper >= 0.24.8-1 for systemd support

* Wed Apr 18 2012 guillomovitch <guillomovitch> 0.9.10-4.mga2
+ Revision: 231331
- systemd support

* Tue Mar 20 2012 tmb <tmb> 0.9.10-3.mga2
+ Revision: 225055
- build against libnl3 (ubuntu, P1)

* Sun Mar 04 2012 misc <misc> 0.9.10-2.mga2
+ Revision: 217731
- add libyajl-devel as BuildRequires, should fix #4685

* Wed Feb 22 2012 ovitters <ovitters> 0.9.10-1.mga2
+ Revision: 212356
- clean spec
- update file list
- new version

* Tue Jan 10 2012 fwang <fwang> 0.9.9-1.mga2
+ Revision: 194440
- new version 0.9.9

* Tue Dec 20 2011 wally <wally> 0.9.8-1.mga2
+ Revision: 184995
- new version 0.9.8

* Tue Dec 06 2011 tv <tv> 0.9.7-1.mga2
+ Revision: 177975
- fix file list
- fix file list
- new release

* Thu Sep 22 2011 fwang <fwang> 0.9.6-1.mga2
+ Revision: 146723
- new version 0.9.6

* Tue Sep 20 2011 fwang <fwang> 0.9.5-1.mga2
+ Revision: 146121
- update file list
- new version 0.9.5
- add provides for libvirt-client
- new version 0.9.4
- add default-stop section
- rebuild for new gnutls

* Tue Jul 19 2011 fwang <fwang> 0.9.3-2.mga2
+ Revision: 126189
- rebuild for new parted

* Tue Jul 05 2011 fwang <fwang> 0.9.3-1.mga2
+ Revision: 118648
- new version 0.9.3

* Tue Jun 21 2011 saispo <saispo> 0.9.2-1.mga2
+ Revision: 111211
- fix typo
- Comment one file
- Update to 0.9.2

* Mon Apr 18 2011 misc <misc> 0.9.0-1.mga1
+ Revision: 87639
- update to 0.9, synced from Mandriva and guillaume rousse work
- drop patch 0, merged upstream
- add BuildRequires on systemtap and pcap-devel

* Tue Apr 05 2011 misc <misc> 0.8.8-3.mga1
+ Revision: 80706
- rebuild
- add patch from upstream, synced from Mandriva
- build with netcf
- use udev rather than hal, change synced from Matthew Dawkins and Mandriva

* Thu Mar 24 2011 boklm <boklm> 0.8.8-2.mga1
+ Revision: 76183
- rebuild for bug #497

* Mon Mar 07 2011 saispo <saispo> 0.8.8-1.mga1
+ Revision: 65995
- New release 0.8.8
+ misc <misc>
- add missing Requires ( without iptables, the network do not work )
+ tmb <tmb>
- imported package libvirt


* Wed Jan 12 2011 Thomas Backlund <tmb@mageia.org> 0.8.6-2.mga1
- initial Mageia import
- drop support for old mandriva releases

* Thu Dec 02 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.6-1mdv2011.0
+ Revision: 604694
- new version

* Thu Nov 11 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.5-1mdv2011.0
+ Revision: 596117
- new version
- fix build (gentoo patch)

* Fri Nov 05 2010 Götz Waschk <waschk@mandriva.org> 0.8.4-2mdv2011.0
+ Revision: 593738
- rebuild for new python 2.7

* Wed Sep 15 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.4-1mdv2011.0
+ Revision: 578760
- update to new version 0.8.4

* Sat Aug 07 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.3-1mdv2011.0
+ Revision: 567285
- new version

* Thu Jul 15 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.2-1mdv2011.0
+ Revision: 553811
- new version

* Tue May 18 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.0-2mdv2010.1
+ Revision: 545263
- fix configuration files list (#59341)

* Wed Apr 14 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.0-1mdv2010.1
+ Revision: 534687
- new version

* Wed Mar 10 2010 Sandro Cazzaniga <kharec@mandriva.org> 0.7.7-1mdv2010.1
+ Revision: 517286
- update to libvirt 0.7.7

* Sat Feb 27 2010 Funda Wang <fwang@mandriva.org> 0.7.6-2mdv2010.1
+ Revision: 512201
- rebuild for new parted

* Thu Feb 04 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.6-1mdv2010.1
+ Revision: 500665
- new version

* Tue Jan 26 2010 Frederic Crozat <fcrozat@mandriva.com> 0.7.5-2mdv2010.1
+ Revision: 496767
- Fix backport for subpackages

* Sun Dec 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.5-1mdv2010.1
+ Revision: 482729
- update to new version 0.7.5

* Sun Dec 27 2009 Funda Wang <fwang@mandriva.org> 0.7.4-3mdv2010.1
+ Revision: 482620
- rebuild for new parted

* Sun Dec 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.4-2mdv2010.1
+ Revision: 474269
- add nfs-utils and xmlrpc-c-devel build dependencies
- don't build xenproxy, it's not useful anymore
- no explicit openvz switch, it's automatically enabled

* Wed Dec 02 2009 Funda Wang <fwang@mandriva.org> 0.7.4-1mdv2010.1
+ Revision: 472618
- New version 0.7.4

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.2-1mdv2010.1
+ Revision: 462073
- Update to new version 0.7.2
- Sync patches with Fedora

* Wed Oct 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-5mdv2010.0
+ Revision: 455681
- Fix patches with Fedora

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 0.7.1-4mdv2010.0
+ Revision: 450013
- fix build on non x86 arches by not enabling xen-proxy, not sure it's
  a lot usefull as qemu on mips is not there (yet. remains a bunch of
  work to do) and qemu on arm is probably broken (from Arnaud Patard)

* Fri Sep 18 2009 Frederic Crozat <fcrozat@mandriva.com> 0.7.1-3mdv2010.0
+ Revision: 444395
- Allow package to be backported on old distributions

* Thu Sep 17 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-2mdv2010.0
+ Revision: 444131
- Fix libification

* Tue Sep 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.1-1mdv2010.0
+ Revision: 443144
- Update to new version 0.7.1
- Remove obsolete patches

* Wed Aug 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-4mdv2010.0
+ Revision: 421544
- Should not depend on GUI package polkit-agent. From Fedora's SPEC, it seems
  polkit is enough

* Wed Aug 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-3mdv2010.0
+ Revision: 421532
- Add Fedora patches (build with polkit-1 now)

* Wed Aug 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.0-2mdv2010.0
+ Revision: 418302
- upstream patch for LXC driver crash (fix #52809)

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 0.7.0-1mdv2010.0
+ Revision: 411753
- Update to new version 0.7.0

* Mon Jul 27 2009 Emmanuel Andry <eandry@mandriva.org> 0.6.5-2mdv2010.0
+ Revision: 400623
- rebuild for new parted

* Sat Jul 04 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.5-1mdv2010.0
+ Revision: 392367
- update to new version 0.6.5

* Tue Jun 09 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.4-1mdv2010.0
+ Revision: 384566
- Remove shared-readonly-label Fedora patch: related to selinux, so
  it's of no use in Mandriva, and Fedora dropped it too now
- Disable test suite for now because it fails with 100HZ kernels
  such as used on build system
- Only enable numa support on 2010.0 and higher

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Updated to 0.6.4.
      Cleaned up no longer needed patches.

* Thu May 21 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-6mdv2010.0
+ Revision: 378339
- Add two patches from Debian:
  * Declare support for QEMU migration in capabilities
  * Don't crash with def == NULL when calling libvirt_lxc without arguments
- Add patches from Fedora:
  * Fix readonly/shared disk image labelling (RH bug #493692)
  * Fix handling of <hostdev managed='yes'> (RH bug #499386)
  * Refresh qemu caps when getCapabilities is called (RH bug #460649)
  * Enable migration with qemu 0.10
  * Don't try to label a disk with no path (e.g. empty cdrom) (RH bug #499569)

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - add numactl support

* Tue May 19 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-4mdv2010.0
+ Revision: 377802
- Add upstream patch fixing kvm --help parsing with kvm 85
- Change init script LSB patch to start after hal and avahi

* Sun May 17 2009 Funda Wang <fwang@mandriva.org> 0.6.3-3mdv2010.0
+ Revision: 376542
- use correct flags

* Wed May 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.3-2mdv2010.0
+ Revision: 372460
- add additional openvz, qemu and avahi support

* Sat May 02 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.3-1mdv2010.0
+ Revision: 370630
- Update to new version 0.6.3
- Remove patches integrated upstream
- Add patch fixing build with -Werror=format-security

* Fri Apr 10 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-3mdv2009.1
+ Revision: 365915
- Don't restart libvirtd when resuming from hibernation, it breaks
  the pipe if virt-manager is left running and does not fix the
  IPv4 forwarding disabled problem after resume anyway

* Fri Mar 27 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-2mdv2009.1
+ Revision: 361522
- libvirtd uses messagebus, so change the init script so that it is
  started later than messagebus
- Add upstream bugfix patches from Fedora
- Restart libvirtd on resume after suspension, otherwise IP forwarding
  is not re-enabled after resume

* Thu Mar 05 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6.1-1mdv2009.1
+ Revision: 349138
- BuildRequires libxml2-utils for xmllint, used by test suite
- Update to new version 0.6.1
- Patch init script to include LSB headers to start network and
  name resolution before libvirt, otherwise libvirt stops working
  if it's started too early
- Run test suite

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-2mdv2009.1
+ Revision: 344754
- rebuild against new readline

* Thu Feb 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.0-1mdv2009.1
+ Revision: 337832
- new version

* Mon Jan 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-3mdv2009.1
+ Revision: 331457
- utils package suggests netcat-openbsd (fix #46465)
- utils package should require same version of the lib
- no tabs, only spaces in spec file

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 0.5.1-2mdv2009.1
+ Revision: 323417
- rebuild

* Mon Dec 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 311991
- new version

* Tue Dec 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.0-1mdv2009.1
+ Revision: 309482
- new version
- disable as_needed, it breaks HAL detection

* Mon Oct 27 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-3mdv2009.1
+ Revision: 297746
- Suggest dnsmasq-base: libvirt uses this package to provide DHCP and
  DNS services to virtual machines with NAT networking
- Create /var/lib/libvirt, where the dnsmasq leases file will be
  stored

* Tue Oct 14 2008 Frederik Himpe <fhimpe@mandriva.org> 0.4.6-2mdv2009.1
+ Revision: 293754
- Make libvirt-utils require bridge-utils, otherwise virsh fails to
  activate the virbr0 bridge

* Mon Oct 13 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.6-1mdv2009.1
+ Revision: 293116
- new version

* Thu Aug 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-2mdv2009.0
+ Revision: 272027
- make devel package requires xen-devel

* Tue Jul 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.4-1mdv2009.0
+ Revision: 230502
- update file list and build dependencies

  + Emmanuel Andry <eandry@mandriva.org>
    - New version

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Apr 16 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.2-1mdv2009.0
+ Revision: 194590
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Mon Jan 21 2008 Funda Wang <fwang@mandriva.org> 0.4.0-3mdv2008.1
+ Revision: 155530
- rebuild

* Tue Dec 18 2007 David Walluck <walluck@mandriva.org> 0.4.0-2mdv2008.1
+ Revision: 132143
- BuildRequires: libsasl-devel
- 0.4.0

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.3-1mdv2008.1
+ Revision: 116159
- new version

* Sat Sep 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.3.2-2mdv2008.0
+ Revision: 92284
- new doc policy
- ship %%{_var}/run/libvirt directory for libvirtd
- fix nasty redefinition of standard GNU directory localstatedir by %%configure macro...

* Thu Aug 30 2007 Funda Wang <fwang@mandriva.org> 0.3.2-1mdv2008.0
+ Revision: 75151
- New version 0.3.2

* Thu Jul 12 2007 Funda Wang <fwang@mandriva.org> 0.3.0-1mdv2008.0
+ Revision: 51565
- fix file list
- New version

* Tue Jun 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.3-1mdv2008.0
+ Revision: 41371
- new version

* Sat Jun 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.2-1mdv2008.0
+ Revision: 34672
- new version


* Fri Feb 23 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.2.0-1mdv2007.0
+ Revision: 125026
- fix build dependencies
- new version
- new version

* Wed Jan 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.10-1mdv2007.1
+ Revision: 109906
- minor spec cleanup
- new version

* Wed Dec 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.1.9-1mdv2007.1
+ Revision: 96226
- new version
- rebuild for latest python

* Mon Oct 16 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-3mdv2006.0
+ Revision: 65351
- remove libxenstore devel requires on x86_64 as well

* Sun Oct 15 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-2mdv2007.1
+ Revision: 65070
- don't require devel(libxenstore), it is not versionned properly

* Sat Oct 14 2006 Olivier Blin <oblin@mandriva.com> 0.1.7-1mdv2006.0
+ Revision: 64654
- buildrequires python-devel
- buildrequires readline-devel
- buildrequires ncurses-devel
- buildrequires libxml2-devel
- buildrequires libxml-devel
- initial libvirt release
- Create libvirt

